import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Content from "../../../src/components/LayoutBuilderContent.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Content.vue", () => {
  describe("with html", () => {
    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection: 1,
        indexSectionBlock: 0,
        slotId: "0",
        element: {
          html: "<div class='foo'></div>"
        }
      },
      store,
      localVue
    });

    it("renders .Content-html with the given html", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-html .foo").length).toBe(1);
    });

    it("doesn't render the Content-placeholder", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-placeholder").length).toBe(
        0
      );
    });
  });

  describe("with html", () => {
    const indexSection = 1;
    const indexSectionBlock = 0;
    const slotId = "0";
    const stub = jest.fn();
    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection,
        indexSectionBlock,
        slotId
      },
      store,
      localVue
    });

    wrapper.setMethods({ showContentOverlay: stub });

    it("doesn't render .Content-html", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-html").length).toBe(0);
    });

    it("renders the Content-placeholder", () => {
      expect(wrapper.findAll(".LayoutBuilderContent-placeholder").length).toBe(
        1
      );
    });

    describe("triggering 'add-content' on the EmpyState", () => {
      it("calls showContentOverlay() witht he correct params", () => {
        wrapper.find("layoutbuilderemptystate-stub").vm.$emit("add-content");
        expect(stub).toHaveBeenCalledWith({
          indexSection,
          slotId,
          indexSectionBlock
        });
      });
    });
  });

  describe("with the section being locked", () => {
    const indexSectionBlock = 0;
    const slotId = "0";

    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection: 3,
        indexSectionBlock,
        slotId
      },
      store,
      localVue
    });

    it("doesnt render the content options", () => {
      expect(wrapper.findAll("layoutbuildercontentoptions-stub").length).toBe(
        0
      );
    });
  });

  describe("with the section not being locked", () => {
    const indexSectionBlock = 0;
    const slotId = "0";

    const wrapper = shallowMount(Content, {
      propsData: {
        indexSection: 1,
        indexSectionBlock,
        slotId
      },
      store,
      localVue
    });

    it("renders the content options", () => {
      expect(wrapper.findAll("layoutbuildercontentoptions-stub").length).toBe(
        1
      );
    });
  });
});
