import { mount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import PageLayout from "../../../src/components/LayoutBuilderPageLayout.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("PageLayout.vue", () => {
  it("'sections' returns the correct array of sections", () => {
    const wrapper = mount(PageLayout, {
      store,
      localVue
    });

    expect(wrapper.vm.sections).toEqual(store.state.sections);
  });

  it("renders the corrent amount of sections", () => {
    const wrapper = mount(PageLayout, {
      store,
      localVue
    });

    expect(wrapper.findAll(".LayoutBuilderPageLayout-item").length).toBe(
      store.state.sections.length
    );
  });

  describe("setting 'sections'", () => {
    it("commits 'updateSectionOrder' with the correct props to the store", () => {
      const value = 3;
      const stub = jest.fn();
      store.commit = stub;

      const wrapper = mount(PageLayout, {
        store,
        localVue
      });

      wrapper.setData({ sections: value });

      expect(stub).toHaveBeenCalledWith("updateSectionOrder", value);
    });
  });
});
