import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Section from "../../../src/components/LayoutBuilderSection.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Section.vue", () => {
  describe("without layout", () => {
    const wrapper = shallowMount(Section, {
      propsData: {
        indexSection: 2,
        section: {
          layout: null
        }
      },
      store,
      localVue
    });

    it("doesnt render section blocks but an empty state", () => {
      expect(wrapper.findAll("layoutbuildersectionblock-stub").length).toBe(0);
      expect(
        wrapper.findAll(
          ".LayoutBuilderSection-layout > layoutbuilderemptystate-stub"
        ).length
      ).toBe(1);
    });
  });

  describe("with layout", () => {
    const indexSection = 1;
    const wrapper = shallowMount(Section, {
      propsData: {
        indexSection,
        section: store.state.sections[indexSection]
      },
      store,
      localVue
    });

    it("doesn't render an empty state but section blocks", () => {
      expect(wrapper.findAll("layoutbuildersectionblock-stub").length).toBe(1);
      expect(
        wrapper.findAll(
          ".LayoutBuilderSection-layout > layoutbuilderemptystate-stub"
        ).length
      ).toBe(0);
    });
  });

  describe("content()", () => {
    const indexSection = 3;
    const wrapper = shallowMount(Section, {
      propsData: {
        indexSection,
        section: {
          content: {
            1: [8],
            2: [8, 9]
          }
        }
      },
      store,
      localVue
    });

    it("returns an Array from 'content' in this section", () => {
      expect(wrapper.vm.content).toEqual(["1", "2"]);
    });
  });

  describe("layout()", () => {
    const wrapper = shallowMount(Section, {
      propsData: {
        indexSection: 0,
        section: {
          layout: "LayoutThreeColumns",
          content: {}
        }
      },
      store,
      localVue
    });

    it("returns the correct layout object", () => {
      expect(wrapper.vm.layout).toEqual(store.state.layouts.LayoutThreeColumns);
    });
  });

  describe("with the section being locked", () => {
    const wrapper = shallowMount(Section, {
      propsData: {
        indexSection: 4,
        section: {
          layout: "LayoutThreeColumns",
          content: {},
          locked: true
        }
      },
      store,
      localVue
    });

    it("doesnt render the section options", () => {
      expect(wrapper.findAll("layoutbuildersectionoptions-stub").length).toBe(
        0
      );
    });
  });

  describe("with the section not being locked", () => {
    const wrapper = shallowMount(Section, {
      propsData: {
        indexSection: 4,
        section: {
          layout: "LayoutThreeColumns",
          content: {},
          locked: false
        }
      },
      store,
      localVue
    });

    it("renders the section options", () => {
      expect(wrapper.findAll("layoutbuildersectionoptions-stub").length).toBe(
        1
      );
    });
  });
});
