import { mount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import SectionBlock from "../../../src/components/LayoutBuilderSectionBlock.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("SectionBlock.vue", () => {
  const indexSection = 1;
  const slotId = "1";

  it("'content' returns the correct array of content blocks", () => {
    const wrapper = mount(SectionBlock, {
      propsData: {
        indexSection,
        slotId
      },
      store,
      localVue
    });

    expect(wrapper.vm.content).toEqual(
      store.state.sections[indexSection].content[slotId]
    );
  });

  it("renders the corrent amount of content blocks in this section block", () => {
    const wrapper = mount(SectionBlock, {
      propsData: {
        indexSection,
        slotId
      },
      store,
      localVue
    });

    expect(wrapper.findAll(".LayoutBuilderContent").length).toBe(
      store.state.sections[indexSection].content[slotId].length
    );
  });

  describe("setting 'content'", () => {
    it("commits 'updateContentOrder' with the correct props to the store", () => {
      const value = 5;
      const stub = jest.fn();
      store.commit = stub;

      const wrapper = mount(SectionBlock, {
        propsData: {
          indexSection,
          slotId
        },
        store,
        localVue
      });

      wrapper.setData({ content: value });

      expect(stub).toHaveBeenCalledWith("updateContentOrder", {
        indexSection,
        slotId,
        value
      });
    });
  });
});
