import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Select from "../../../src/components/LayoutBuilderSelect.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Select.vue", () => {
  const stub = jest.fn();
  Select.methods.changeLayout = stub;

  const wrapper = shallowMount(Select, {
    propsData: {
      indexSection: 1,
      section: {
        layout: "LayoutOneColumn"
      }
    },
    store,
    localVue
  });

  it("uses the first item of each entry in layouts for the values of the select", () => {
    expect(wrapper.find("option:nth-child(1)").attributes().value).toBe("");
    expect(wrapper.find("option:nth-child(2)").attributes().value).toBe(
      "LayoutOneColumn"
    );
    expect(wrapper.find("option:nth-child(3)").attributes().value).toBe(
      "LayoutThreeColumns"
    );
  });

  it("uses the second item of each entry in layouts for the names of the select", () => {
    expect(wrapper.find("option:nth-child(1)").text()).toBe("- Layout -");
    expect(wrapper.find("option:nth-child(2)").text()).toBe("One column");
    expect(wrapper.find("option:nth-child(3)").text()).toBe("Three columns");
  });

  it("sets the value of the component to section.layout", () => {
    expect(wrapper.element.value).toBe("LayoutOneColumn");
  });

  it("calls changeLayout() with the correct params when changing the select", () => {
    wrapper.element.value = "LayoutThreeColumns";
    wrapper.trigger("change");
    expect(Select.methods.changeLayout).toHaveBeenCalledWith({
      indexSection: 1,
      selectedLayout: "LayoutThreeColumns"
    });
  });

  describe("layouts()", () => {
    it("returns an array with arrays including the keys and names of the layouts", () => {
      expect(wrapper.vm.layouts).toEqual([
        ["LayoutOneColumn", "One column"],
        ["LayoutThreeColumns", "Three columns"],
        ["LayoutTwoColumns", "Two columns"]
      ]);
    });
  });
});
