import { shallowMount, mount } from "@vue/test-utils";
import IconButton from "../../../../src/components/buttons/_LayoutBuilderBase.vue";

describe("IconButton.vue", () => {
  it("calls onClick() when clicking on the component", () => {
    const wrapper = shallowMount(IconButton);
    const stub = jest.fn();
    wrapper.setMethods({ onClick: stub });
    wrapper.trigger("click");
    expect(stub).toHaveBeenCalled();
  });

  it("calling onClick() does nothing since it will be overwritten by extending component", () => {
    const wrapper = shallowMount(IconButton);
    expect(wrapper.vm.onClick()).toBe(false);
  });

  describe("if there is no icon component", () => {
    const wrapper = shallowMount(IconButton);

    it("iconComponentAvailable() returns false", () => {
      expect(wrapper.vm.iconComponentAvailable()).toBe(false);
    });

    it("doesn't render an Icon", () => {
      expect(wrapper.findAll("icon-stub").length).toBe(0);
    });
  });

  describe("if there is an icon component", () => {
    const wrapper = mount(IconButton, {
      stubs: ["Icon"]
    });

    it("iconComponentAvailable() returns true", () => {
      expect(wrapper.vm.iconComponentAvailable()).toBe(true);
    });

    it("renders an Icon", () => {
      expect(wrapper.findAll("icon-stub").length).toBe(1);
    });
  });
});
