import cloneDeep from "clone-deep";
import actions from "../../../src/store/actions";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const store = Store(state);

describe("actions", () => {
  const data = {
    id: "element1",
    element: {
      html: "foo"
    }
  };
  const stub = jest.fn();
  store.commit = stub;

  afterEach(() => {
    store.replaceState(cloneDeep(state));
  });

  describe("editContent()", () => {
    describe("when the passed element doesn't exit in the state yet", () => {
      it("commits addElement with the passed data to the store", () => {
        actions.editContent(store, data);
        expect(stub).toHaveBeenCalledWith("addElement", data);
      });
    });

    describe("when the passed element exists in the state", () => {
      it("commits updateElement with the passed to the store", () => {
        const props = {
          id: "element7",
          element: {
            html: "foo"
          }
        };
        actions.editContent(store, props);
        expect(stub).toHaveBeenCalledWith("updateElement", props);
      });
    });

    it("commits editContent on the store", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("editContent", data);
    });

    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentOverlayVisibility on the store with false", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setContentOverlayVisibility", false);
    });
  });

  describe("showContentOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with data", () => {
      actions.showContentOverlay(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", data);
    });

    it("commits setContentOverlayVisibility on the store with true", () => {
      actions.showContentOverlay(store, data);
      expect(stub).toHaveBeenCalledWith("setContentOverlayVisibility", true);
    });
  });

  describe("closeContentOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.closeContentOverlay(store);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentOverlayVisibility on the store with false", () => {
      actions.closeContentOverlay(store);
      expect(stub).toHaveBeenCalledWith("setContentOverlayVisibility", false);
    });
  });
});
